==> meta-0.1.0-20170515.000841-3.jar: nodejs.out/cljs/nodejs.js <==
// Compiled by ClojureScript 1.9.521 {:target :nodejs}
goog.provide('cljs.nodejs');
goog.require('cljs.core');
cljs.nodejs.require = require;
cljs.nodejs.process = process;
cljs.nodejs.enable_util_print_BANG_ = (function cljs$nodejs$enable_util_print_BANG_(){
cljs.core._STAR_print_newline_STAR_ = false;

cljs.core._STAR_print_fn_STAR_ = (function() { 
var G__8349__delegate = function (args){
return console.log.apply(console,cljs.core.into_array.call(null,args));
};
var G__8349 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__8350__i = 0, G__8350__a = new Array(arguments.length -  0);
while (G__8350__i < G__8350__a.length) {G__8350__a[G__8350__i] = arguments[G__8350__i + 0]; ++G__8350__i;}
  args = new cljs.core.IndexedSeq(G__8350__a,0);
} 
return G__8349__delegate.call(this,args);};
G__8349.cljs$lang$maxFixedArity = 0;
G__8349.cljs$lang$applyTo = (function (arglist__8351){
var args = cljs.core.seq(arglist__8351);
return G__8349__delegate(args);
});
G__8349.cljs$core$IFn$_invoke$arity$variadic = G__8349__delegate;
return G__8349;
})()
;

cljs.core._STAR_print_err_fn_STAR_ = (function() { 
var G__8352__delegate = function (args){
return console.error.apply(console,cljs.core.into_array.call(null,args));
};
var G__8352 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__8353__i = 0, G__8353__a = new Array(arguments.length -  0);
while (G__8353__i < G__8353__a.length) {G__8353__a[G__8353__i] = arguments[G__8353__i + 0]; ++G__8353__i;}
  args = new cljs.core.IndexedSeq(G__8353__a,0);
} 
return G__8352__delegate.call(this,args);};
G__8352.cljs$lang$maxFixedArity = 0;
G__8352.cljs$lang$applyTo = (function (arglist__8354){
var args = cljs.core.seq(arglist__8354);
return G__8352__delegate(args);
});
G__8352.cljs$core$IFn$_invoke$arity$variadic = G__8352__delegate;
return G__8352;
})()
;

return null;
});

//# sourceMappingURL=nodejs.js.map

==> meta-0.1.0-20170516.183006-5.jar: nodejs.out/cljs/nodejs.js <==
// Compiled by ClojureScript 1.9.542 {:target :nodejs}
goog.provide('cljs.nodejs');
goog.require('cljs.core');
cljs.nodejs.require = require;
cljs.nodejs.process = process;
cljs.nodejs.enable_util_print_BANG_ = (function cljs$nodejs$enable_util_print_BANG_(){
cljs.core._STAR_print_newline_STAR_ = false;

cljs.core._STAR_print_fn_STAR_ = (function() { 
var G__8352__delegate = function (args){
return console.log.apply(console,cljs.core.into_array.call(null,args));
};
var G__8352 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__8353__i = 0, G__8353__a = new Array(arguments.length -  0);
while (G__8353__i < G__8353__a.length) {G__8353__a[G__8353__i] = arguments[G__8353__i + 0]; ++G__8353__i;}
  args = new cljs.core.IndexedSeq(G__8353__a,0,null);
} 
return G__8352__delegate.call(this,args);};
G__8352.cljs$lang$maxFixedArity = 0;
G__8352.cljs$lang$applyTo = (function (arglist__8354){
var args = cljs.core.seq(arglist__8354);
return G__8352__delegate(args);
});
G__8352.cljs$core$IFn$_invoke$arity$variadic = G__8352__delegate;
return G__8352;
})()
;

cljs.core._STAR_print_err_fn_STAR_ = (function() { 
var G__8355__delegate = function (args){
return console.error.apply(console,cljs.core.into_array.call(null,args));
};
var G__8355 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__8356__i = 0, G__8356__a = new Array(arguments.length -  0);
while (G__8356__i < G__8356__a.length) {G__8356__a[G__8356__i] = arguments[G__8356__i + 0]; ++G__8356__i;}
  args = new cljs.core.IndexedSeq(G__8356__a,0,null);
} 
return G__8355__delegate.call(this,args);};
G__8355.cljs$lang$maxFixedArity = 0;
G__8355.cljs$lang$applyTo = (function (arglist__8357){
var args = cljs.core.seq(arglist__8357);
return G__8355__delegate(args);
});
G__8355.cljs$core$IFn$_invoke$arity$variadic = G__8355__delegate;
return G__8355;
})()
;

return null;
});

//# sourceMappingURL=nodejs.js.map
